@@ -4,23 +4,25 @@ from __future__ import annotations
 
 import os
 import shutil
-from typing import ClassVar
+from typing import TYPE_CHECKING, ClassVar
 
 from dmgbuild.core import DMGError, build_dmg
 from setuptools import Command
 
-import cx_Freeze.icons
-from cx_Freeze import Executable
+from cx_Freeze.common import resource_path
 from cx_Freeze.exception import OptionError, PlatformError
 
+if TYPE_CHECKING:
+    from cx_Freeze import Executable
+
 __all__ = ["bdist_dmg"]
 
 
 class bdist_dmg(Command):
-    """Create a Mac DMG disk image containing the Mac application bundle."""
+    """Create a macOS DMG disk image containing the application bundle."""
 
     description = (
-        "create a Mac DMG disk image containing the Mac application bundle"
+        "create a macOS DMG disk image containing the macOS application bundle"
     )
     user_options: ClassVar[list[tuple[str, str | None, str]]] = [
         ("volume-label=", None, "Volume label of the DMG disk image"),
@@ -85,18 +87,18 @@ class bdist_dmg(Command):
             "window-rect",
             None,
             "Window rectangle in the form x, y, width, height. The position "
-            "of the window in ((x, y), (w, h)) format, with y co-ordinates "
+            "of the window in ((x, y), (w, h)) format, with y coordinates "
             "running from bottom to top. The Finder makes sure that the "
             "window will be on the user's display, so if you want your window "
             "at the top left of the display you could use (0, 100000) as the "
-            "x, y co-ordinates. Unfortunately it doesn't appear to be "
+            "x, y coordinates. Unfortunately it doesn't appear to be "
             "possible to position the window relative to the top left or "
             "relative to the centre of the user's screen.",
         ),
         (
             "icon-locations",
             None,
-            "A dictionary specifying the co-ordinates of items in the root "
+            "A dictionary specifying the coordinates of items in the root "
             "directory of the disk image, where the keys are filenames and "
             "the values are (x, y) tuples. e.g.: "
             'icon-locations = { "Applications": (100, 100), '
@@ -257,8 +259,7 @@ class bdist_dmg(Command):
             )
         if executable.icon is None:
             icon_name = "setup.icns"
-            icon_source_dir = os.path.dirname(cx_Freeze.icons.__file__)
-            self.icon = os.path.join(icon_source_dir, icon_name)
+            self.icon = os.fspath(resource_path(f"icons/{icon_name}"))
         else:
             self.icon = os.path.abspath(executable.icon)
 
