@@ -27,6 +27,7 @@ from cx_Freeze._compat import (
     IS_CONDA,
     IS_MACOS,
     IS_MINGW,
+    IS_UCRT,
     IS_WINDOWS,
     PYTHON_VERSION,
 )
@@ -140,8 +141,8 @@ class Freezer:
         self.compress: bool = True if compress is None else compress
         self.optimize: int = int(optimize or 0)
         self.path: list[str] | None = self._validate_path(path)
-        # include-msvcr is used on Windows, but not in MingW
-        self.include_msvcr: bool = IS_WINDOWS and bool(include_msvcr)
+        # include-msvcr is used on Windows and some MSYS2 environments
+        self.include_msvcr: bool = IS_UCRT and bool(include_msvcr)
         self.include_msvcr_version: str | None = include_msvcr_version
         self.target_dir = target_dir
         self.default_bin_includes: list[str] = self._default_bin_includes()
@@ -274,12 +275,15 @@ class Freezer:
     def _copy_package_data(self, module: Module, target_dir: Path) -> None:
         """Copy any non-Python files to the target directory."""
         ignore_patterns = [
-            "*.pxd",
+            "*.c",
+            "*.cpp",
+            "*.pxd",  # cython declaration file
+            "*.pxi",  # cython include file
             "*.py",
             "*.pyc",
-            "*.pyi",
+            "*.pyi",  # python stub files
             "*.pyo",
-            "*.pyx",
+            "*.pyx",  # cython source
             "__pycache__",
             "py.typed",
         ]
@@ -547,6 +551,12 @@ class Freezer:
                         index = path.index(dest_shared)
                         path.pop(index)
                 path.insert(index, os.path.normpath(core_lib))
+        # remove setuptools._vendor path
+        path_vendor = os.path.join("setuptools", "_vendor")
+        for index, p in enumerate(path):
+            if p.endswith(path_vendor):
+                path.pop(index)
+                break
         return path
 
     @staticmethod
