@@ -6,7 +6,9 @@ import sys
 
 import pytest
 
-TIMEOUT = 10
+from cx_Freeze._compat import ABI_THREAD
+
+TIMEOUT = 15
 
 if sys.platform != "win32":
     pytest.skip(reason="Windows tests", allow_module_level=True)
@@ -16,6 +18,12 @@ zip_packages = pytest.mark.parametrize(
 )
 
 
+@pytest.mark.xfail(
+    ABI_THREAD == "t",
+    raises=ModuleNotFoundError,
+    reason="pywin32 does not support Python 3.13t/3.14t",
+    strict=True,
+)
 @pytest.mark.venv(scope="module")
 @zip_packages
 def test_win32com(tmp_package, zip_packages: bool) -> None:
@@ -68,6 +76,12 @@ pyproject.toml
 """
 
 
+@pytest.mark.xfail(
+    ABI_THREAD == "t",
+    raises=ModuleNotFoundError,
+    reason="pywin32 does not support Python 3.13t/3.14t",
+    strict=True,
+)
 @pytest.mark.venv(scope="module")
 @zip_packages
 def test_win32com_shell(tmp_package, zip_packages: bool) -> None:
